@@ -19,4 +19,7 @@ if not 'BASE_STREAM_NAME' in os.environ:
 
 os.environ['USER_COMPUTER'] = os.environ['USERNAME']+'@'+os.environ['COMPUTERNAME']
 
+if not 'LOG_LEVEL' in os.environ:    
+    os.environ['LOG_LEVEL']='INFO'
+
 loaded=True
\ No newline at end of file
