@@ -85,7 +85,7 @@ class Logger:
             self.log.addHandler(fhandler)
             #log to aws kinesis
             kinesishandler = KinesisLogStreamHandler(user=Logger.user)
-            kinesishandler.setLevel(loglevel)
+            kinesishandler.setLevel(logging.DEBUG)
             jsonformatter = JsonFormatter(os.environ['USERNAME']+'@'+os.environ['COMPUTERNAME'] + 
                 ';%(asctime)s;%(name)s;%(levelname)s;%(message)s',\
                 datefmt='%Y-%m-%dT%H:%M:%S%z')
@@ -94,10 +94,10 @@ class Logger:
             #assign static variable log to be used by modules
             Logger.log = self.log
             try:
-                Logger.log.info('Logger initialized shareddata user %s version %s!' % \
+                Logger.log.debug('Logger initialized shareddata user %s version %s!' % \
                     (Logger.user,version('SharedData')))
             except:
-                Logger.log.info('Logger initialized shareddata!')
+                Logger.log.debug('Logger initialized shareddata!')
         
     def readLogs(self):    
         logsdir = Path(os.environ['LOG_PATH']).parents[0]
