@@ -12,12 +12,11 @@ from SharedData.SharedDataAWSS3 import S3SyncDownloadMetadata,S3Upload
 
 class Metadata():
     
-    def __init__(self, name, mode='rw', user='master',debug=False):
-        self.debug = debug
-
+    def __init__(self, name, mode='rw', user='master'):
+        
         if Logger.log is None:
             Logger('Metadata')
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Initializing Metadata %s,%s,%s ...' % (user,name,mode))
         self.user = user
         
@@ -58,7 +57,7 @@ class Metadata():
         
         if readpkl:
             tini = time.time()
-            if self.debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Loading metadata pkl ' + name + ' ...')
             self.static = pd.read_pickle(self.pathpkl)
             self.static = self.static.sort_index()
@@ -68,7 +67,7 @@ class Metadata():
             if self.pathseries.is_file():
                 self.series = pd.read_pickle(self.pathseries)
                 self.series = self.series.sort_index()
-            if self.debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Loading metadata pkl %s %.2f done!' % (name,time.time()-tini))
 
         elif readxlsx:
@@ -82,15 +81,15 @@ class Metadata():
                 self.static = self.static.set_index(self.static.columns[0])
             if not self.symbols.empty:
                 self.symbols = self.symbols.set_index(self.symbols.columns[0])
-            if self.debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Loading metadata xlsx %s %.2f done!' % (name,time.time()-tini))
         
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Initializing Metadata %s,%s DONE!' % (name,mode))
 
     def save(self,save_excel=False):
         tini = time.time()
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Saving metadata ' + self.name + ' ...')  
         if not os.path.isdir(self.pathpkl.parents[0]):
             os.makedirs(self.pathpkl.parents[0])                   
@@ -106,21 +105,30 @@ class Metadata():
             if self.s3write:
                 S3Upload(self.pathxls)
 
-        self.static.to_pickle(self.pathpkl)
+        with open(self.pathpkl, 'wb') as f:
+            self.static.to_pickle(f)
+            f.flush()
+
         if self.s3write:
             S3Upload(self.pathpkl)
 
         if not self.symbols.empty:
-            self.symbols.to_pickle(self.pathsymbols)
+            with open(self.pathsymbols, 'wb') as f:
+                self.symbols.to_pickle(f)
+                f.flush()
+
             if self.s3write:
                 S3Upload(self.pathsymbols)
 
         if not self.series.empty:
-            self.series.to_pickle(self.pathseries)
+            with open(self.pathseries, 'wb') as f:
+                self.series.to_pickle(f)
+                f.flush()
+                
             if self.s3write:
                 S3Upload(self.pathseries)
 
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Saving metadata ' + self.name + \
                 ' %.2f done!' % (time.time()-tini))
     
