@@ -23,7 +23,10 @@ class KinesisLogStreamHandler(logging.StreamHandler):
 
         try:
             session = boto3.Session()
-            self.datastream = session.client('kinesis')
+            if 'KINESIS_ENDPOINT_URL' in os.environ:
+                self.datastream = session.client('kinesis',endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
+            else:
+                self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
 
@@ -108,9 +111,16 @@ class KinesisLogStreamConsumer():
 
         return self.dflogs
     
-    def connect(self):                
+    def connect(self):
         session = boto3.Session()
-        self.client = session.client('kinesis')
+        if 'KINESIS_ENDPOINT_URL' in os.environ:            
+            self.client = session.client('kinesis',\
+                endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
+        else:
+            self.client = session.client('kinesis')
+            
+
+        
         self.stream = self.client.describe_stream(StreamName=os.environ['LOG_STREAMNAME'])
         if self.stream and 'StreamDescription' in self.stream:
             self.stream = self.stream['StreamDescription']
@@ -175,7 +185,10 @@ class KinesisStreamProducer():
         self.stream_buffer = []
         try:
             session = boto3.Session()
-            self.datastream = session.client('kinesis')
+            if 'KINESIS_ENDPOINT_URL' in os.environ:
+                self.datastream = session.client('kinesis',endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
+            else:
+                self.datastream = session.client('kinesis')
         except Exception:
             print('Kinesis client initialization failed.')
 
@@ -200,7 +213,10 @@ class KinesisStreamConsumer():
     def get_stream(self):
         print('Initializing stream...')
         session = boto3.Session()
-        self.client = session.client('kinesis')
+        if 'KINESIS_ENDPOINT_URL' in os.environ:
+            self.datastream = session.client('kinesis',endpoint_url=os.environ['KINESIS_ENDPOINT_URL'])
+        else:
+            self.datastream = session.client('kinesis')
         self.stream = self.client.describe_stream(StreamName=self.stream_name)
         if self.stream and 'StreamDescription' in self.stream:
             self.stream = self.stream['StreamDescription']
