@@ -274,23 +274,29 @@ class SharedDataTimeSeries:
     def Read(self):   
         path, shm_name = self.getDataPath()        
         years = [int(x.stem) for x in path.glob('*.npy') if x.is_file()]
-        fpaths = [x for x in path.glob('*.npy') if x.is_file()]        
-        mtime = [datetime.fromtimestamp(os.stat(f).st_mtime) for f in fpaths]
-        self.last_update = max(mtime)
-        self.first_update = min(mtime)        
-        files = pd.DataFrame([years,fpaths]).T
-        files.columns = ['year','fpath']
-        files = files.sort_values(by='year')
-        nfiles = len(files.index)
-        if nfiles>0:
-            tini=time.time()
-            if os.environ['LOG_LEVEL']=='DEBUG':
-                Logger.log.debug('Reading %s ...%.2f%% ' % (shm_name,0.0))   
-            n=0
-            self.read_multithread(files['fpath'])
-            if os.environ['LOG_LEVEL']=='DEBUG':
-                Logger.log.debug('Reading %s ...%.2f%% %.2f sec! ' % \
-                    (shm_name,100*(n/nfiles),time.time()-tini))
+        fpaths = [x for x in path.glob('*.npy') if x.is_file()]
+        if len(fpaths)>0:
+            mtime = [datetime.fromtimestamp(os.stat(f).st_mtime) for f in fpaths]
+            if len(mtime)>0:
+                self.last_update = max(mtime)
+                self.first_update = min(mtime)
+            else:
+                self.last_update = pd.NaT
+                self.first_update = pd.NaT
+                
+            files = pd.DataFrame([years,fpaths]).T
+            files.columns = ['year','fpath']
+            files = files.sort_values(by='year')
+            nfiles = len(files.index)
+            if nfiles>0:
+                tini=time.time()
+                if os.environ['LOG_LEVEL']=='DEBUG':
+                    Logger.log.debug('Reading %s ...%.2f%% ' % (shm_name,0.0))   
+                n=0
+                self.read_multithread(files['fpath'])
+                if os.environ['LOG_LEVEL']=='DEBUG':
+                    Logger.log.debug('Reading %s ...%.2f%% %.2f sec! ' % \
+                        (shm_name,100*(n/nfiles),time.time()-tini))
 
     def read_multithread(self,file_paths):
         # create a thread pool
